@@ -228,7 +228,7 @@ class GbpOptionParser(OptionParser):
             "Use pristine-tar to create orig tarball, "
             "default is '%(pristine-tar)s'",
         'pristine-tar-commit':
-            "When generating a tarball commit it to the pristine-tar branch '%(pristine-tar-commit)s' "
+            "When generating a tarball, commit it to the pristine-tar branch '%(pristine-tar-commit)s' "
             "default is '%(pristine-tar-commit)s'",
         'filter-pristine-tar':
             "Filter pristine-tar when filter option is used, default is '%(filter-pristine-tar)s'",
